function arrindex = arrcoord2index(coord,dims) 
# usage: arrindex = arrcoord2index(coord,dims) 
#
# This function takes a set of indices in column vector of indices "coord", 
# and then computes the array index "arrindex" corresponding to the 
# specified coordinates in a multidimensional array of dimensions 
# given by the column vector "dims".
#
# For example, for coord=[2; 1] with a 2 X 3 matrix (dims=[2; 3]):
#     arrindex=4
# For example, for coord=[1; 1; 4] with a 2 X 3 X 4 matrix (dims=[2; 3; 4]):
#     arrindex=4

# Author:  Ronald Kumon

  # Error checking
  if ( nargin != 2 )
    usage("arrcoord2index(coord,dims)");
  endif

  if ( is_vector(coord) != 1 )
    error("Specified coordinates are not in vector form.")
  end

  if ( is_vector(dims) != 1 )
    error("Specified dimensions are not in vector form.")
  end  

  if ( length(coord) > length (dims) )
    error("The number of coordinates exceeds the number of dimensions.")
  end

  for index=1:length(coord)
    if ( ( coord(index) > dims(index) ) || ( coord(index) < 1 ) )
      error("Index value not in dimensional range.")
    end
  end

  # Verify that vector are in column form
  # (It does make a difference because flipud.m is used below!)
  coordsize=size(coord);
  if ( coordsize(1)==1 )
    coord=coord.';
  end
  dimssize=size(dims);
  if ( dimssize(1)==1 )
    dims=dims.';
  end

  # Compute array index 
  ndim=length(dims);
  if ( ndim==1 )
    arrindex=coord;
  else
    basevec=[flipud(cumprod(flipud(dims(2:ndim)))); 1];
    arrindex=sum(basevec.*(coord-1))+1;
  end

endfunction

