function X = arrdef(d,k) 
# usage: X = arrdef(d,k) 
#
# This function generates a structure which contains the information 
# needed to define a multidimensional array.  The value "d" is the 
# dimension of the array and "k" is a vector which contains the number of 
# indices in each dimension.  The array is initially assign to contain all 
# zeros.  Note that X.dim and X.elem are always defined as column vectors.

# Author:  Ronald Kumon

  # Error checking
  if ( nargin != 2 )
    usage("arrdef(d,k)");
  endif

  if ( is_scalar(d) != 1 )
    error("Specified dimension is not a scalar.")
  end

  if ( is_vector(k) != 1 )
    error("Specified index ranges are not in vector form.")
  end

  if ( ( d < 0 ) ||  ( rem(d,1) != 0 ) )
    error("Dimension must be a non-negative integer.")
  end

  for index=1:length(k)
    if ( k(index) < 0 ||  ( rem(k(index),1) != 0 ) )
      error("Index range values must be positive integers.")
    end
  end

  if ( length(k) != d )
    error("Number of indices does not match number of dimensions.")
  end

  # Define multidimensional array except for elements
  X.ndim = d;

  if ( rows(k) == 1 )
    X.dims = k.';
  else
    X.dims = k;   
  end

  X.elems=zeros(prod(k),1);

endfunction

