function Z = arrdirprod(X,Y)
# usage: Z = arrdirprod(X,Y)  
#
# This function constructs the direct product of the multidimensional arrays
# "X" and "Y" and puts the result in to the new multidimensional array "Z".

# Author:  Ronald Kumon

  # Error checking
  if ( nargin != 2 )
    usage("arrdirprod(X,Y)");
  endif

  if ( is_struct(X) != 1 )
    error("Input argument is not a multidimensional array structure.")
  end

  if ( is_struct(Y) != 1 )
    error("Input argument is not a multidimensional array structure.")
  end

  if ( ( X.ndim== 0 ) || ( Y.ndim== 0 ) )
    error("Direct products cannot be formed with scalars.  Use arrscalmult(a,X).")
  end

  Z.ndim=X.ndim+Y.ndim;
  Z.dims=[X.dims; Y.dims];

  for index=1:prod(Z.dims)
    Zcoord=arrindex2coord(index,Z.dims);
    Xcoord=Zcoord(1:X.ndim);
    Ycoord=Zcoord(X.ndim+1:Z.ndim);
    Xarrindex=arrcoord2index(Xcoord,X.dims);
    Yarrindex=arrcoord2index(Ycoord,Y.dims);
    X.elems(Xarrindex);
    Y.elems(Yarrindex);
    Z.elems(index)=X.elems(Xarrindex)*Y.elems(Yarrindex);
  end

endfunction

