function x = arrelemval(X,coord) 
# usage: x = arrelemval(X,coord)   
#
# This function displays the element value of the multidimensional array "X" 
# given by a multidimensional vector of indices "coord".
#
# Uses:  arrcoord2index.m

# Author:  Ronald Kumon

  # Error checking
  if ( nargin != 2 )
    usage("arrelemval(X,coord)");
  endif

  if ( is_struct(X) != 1 )
    error("Input argument is not a multidimensional array structure.")
  end

  if ( is_vector(coord) != 1 )
    error("Specified coordinates are not in vector form.")
  end

  d = X.ndim; 
  k = X.dims; 

  if ( d == 0 )
    x=X.elems;
  else
    if ( length(coord) != d )
      error("Number of specified indices does not equal number of dimensions.")
    end
    for r=1:length(k)
      if ( ( coord(r) < 1    )      || \ 
           ( coord(r) > k(r) )      || \ 
           ( rem(coord(r),1) != 0 ) )
        error("Specified indices are out of bounds.")
      end 
    end
    # Compute array index from coordinates
    arrindex=arrcoord2index(coord,k);
    # Output element value
    x = X.elems(arrindex);
  end

endfunction

