function coord = arrindex2coord(arrindex,dims) 
# usage: coord = arrindex2coord(arrindex,dims) 
#
# This function takes the array index "arrindex" of a multidimensional array
# defined by its dimensions in the column vector "dims", 
# and then computes the coordinates "coord" corresponding to that array 
# index.
#
# For example, for arrindex=4 with a 2 X 3 matrix (dims=[2; 3]):
#    coord=[2; 1]
# For example, for arrindex=4 with a 2 X 3 X 4 matrix (dims=[2; 3; 4]):
#    coord=[1; 1; 4]

# Author:  Ronald Kumon

  # Error checking
  if ( nargin != 2 )
    usage("arrindex2coord(arrindex,dims)");
  endif

  if ( is_scalar(arrindex) != 1 )
    error("Specified array index is not a scalar.")
  end

  if ( is_vector(dims) != 1 )
    error("Specified dimensions are not in vector form.")
  end  

  arrsize=prod(dims);
  if ( ( arrindex > arrsize ) || ( arrindex < 1 ) )
    error("Specified array index falls outside of array dimensions.")
  end

  # Verify that vector are in column form
  # (It does make a difference because flipud.m is used below!)
  dimssize=size(dims);
  if ( dimssize(1)==1 )
    dims=dims.';
  end

  # Compute coordinates
  ndim=length(dims);
  if ( ndim == 1 )
    coord=arrindex;
  else
    temp=arrindex-1;
    basevec=[flipud(cumprod(flipud(dims(2:ndim)))); 1];
    for index=1:ndim
      coord(index)=floor(temp/basevec(index))+1;
      temp=rem(temp,basevec(index));
    end
  end

endfunction

