function y=arrindexorder(dims)
# usage: y=arrindexorder(dims) 
#
#This function produces a matrix where each row contains the indices 
#of a multidimensional array with dimensions given by the column vector 
#"dims".  
#
#  For example, for a matrix in 3-space (dims=[3; 3]):
#        y=[1 1; 1 2; 1 3; 2 1; 2 2; 2 3; 3 1; 3 2; 3 3]
#  For example, for a 2 X 3 matrix (dims=[2; 3]):
#        y=[1 1; 1 2; 1 3; 2 1; 2 2; 2 3]
#  For example, for a 2 X 3 X 4 array (dims=[2; 3; 4]):
#        y=[1 1 1; 1 1 2; 1 1 3; 1 1 4; \
#           1 2 1; 1 2 2; 1 2 3; 1 2 4; \
#           1 3 1; 1 3 2; 1 3 3; 1 3 4; \
#           2 1 1; 2 1 2; 2 1 3; 2 1 4; \
#           2 2 1; 2 2 2; 2 2 3; 2 2 4; \ 
#           2 3 1; 2 3 2; 2 3 3; 2 3 4]
#
# Uses:  arrindex2coord.m

# Author:  Ronald Kumon

  # Error checking
  if ( nargin != 1 )
    usage("arrindexorder(dims) ");
  endif

  if ( is_vector(dims) != 1 )
    error("Specified index range is not in vector form.")
  end

 # Compute total size of matrix
 arraysize=prod(dims);
 for arrindex=1:arraysize
   coord(arrindex,:)=arrindex2coord(arrindex,dims).';
 end
 y=coord;

endfunction

