function y=arrindexorderdec(dims)
# usage: y=arrindexorderdec(dims) 
#
#This function produces a column vector with the the decimal contents 
#of each element correspond the indices of a multidimensional array 
#with dimensions given by the column vector "dims".  This is really only
#intuitive when the number of indices in each dimension is less than ten,
#but a standard test matrix will be generated in any case.
#
#  For example, for a matrix in 3-space (dims=[3; 3]):
#        y=[11; 12; 13; 21; 22; 23; 31; 32; 33]
#  For example, for a 2 X 3 matrix (dims=[2; 3]):
#        y=[11; 12; 13; 21; 22; 23]
#  For example, for a 2 X 3 X 4 array (dims=[2; 3; 4]):
#        y=[111; 112; 113; 114; 121; 122; 123; 124; 131; 132; 133; 134; \
#           211; 212; 213; 214; 221; 222; 223; 224; 231; 232; 233; 234]
#
# Uses:  arrindex2coord.m

# Author:  Ronald Kumon

  # Error checking
  if ( nargin != 1 )
    usage("arrindexorderdec(dims) ");
  endif

  if ( is_vector(dims) != 1 )
    error("Specified index range is not in vector form.")
  end

 # Compute total size of matrix
 arraysize=prod(dims);
 for arrindex=1:arraysize
   coord(arrindex,:)=arrindex2coord(arrindex,dims).';
   decimalcoord(arrindex)=polyval(coord(arrindex,:),10);
 end
 y=decimalcoord;

endfunction

