function Z = arrindexperm(X,indexperm) 
# usage: Z = arrindexperm(X,indexperm)   
#
# This function takes the multidimensional array "X", 
# permutes the indices according to the cyclic permutation 
# specified in "indexperm", and outputs the result to 
# a new multidimensional array "Z".
#
# Uses:  arrindexorder.m, arrcoord2index.m

# Author:  Ronald Kumon

  # Error checking
  if ( nargin != 2 )
    usage("arrindexperm(X,indexperm)");
  endif

  if ( is_struct(X) != 1 )
    error("Input argument is not a multidimensional array structure.")
  end

  if ( is_vector(indexperm) != 1 )
    error("Specified transpose indices are not in vector form.")
  end

  # Dimension of permuted array
  Z.ndim=X.ndim;

  # Index ranges of permuted array
  Z.dims=X.dims(indexperm);

  # Elements of permuted array
  Xcoord=arrindexorder(X.dims);
  Xcoordperm=Xcoord(:,indexperm);  
  for index=1:prod(X.dims)
    Xarrindex=arrcoord2index(Xcoordperm(index,:),Z.dims);
    Z.elems(Xarrindex)=X.elems(index);
  end

endfunction

