function trace = arrtrace(X) 
# usage: trace = arrtrace(X)   
#
# This function takes trace of the multidimensional tensor "X" 
# (sums all the elements in which indices are all identical).
#
# Uses:  is_tensor.m, arrcoord2index.m

# Author:  Ronald Kumon

  # Error checking
  if ( nargin != 1 )
    usage("arrtrace(X)");
  endif

  if ( is_struct(X) != 1 )
    error("Input argument is not a multidimensional array structure.")
  end

  if ( is_tensor(X) != 1 )
    error("Specified array must be a tensor to take trace.")
  end

  ndim=X.ndim;
  dims=X.dims(1);

  if ( ndim == 0 )
    trace=X.elems;
  else
    trace=0;
    for index=1:dims
      coord=index*ones(1,ndim);
      arrindex=arrcoord2index(coord,X.dims);
      trace=trace+X.elems(arrindex);
    end
  end

endfunction

