function Z = arrtranspose(X) 
# usage: Z = arrtranspose(X)   
#
# This function takes the matrix transpose of the two dimensional array "X"
# and puts the result into a new two dimensional array "Z".  It is 
# equivalent to arrindexperm(X,[2 1]).
#
# Uses:  arrindexorder.m, arrcoord2index

# Author:  Ronald Kumon

  # Error checking
  if ( nargin != 1 )
    usage("arrtranspose(X)");
  endif

  if ( is_struct(X) != 1 )
    error("Input argument is not a multidimensional array structure.")
  end

  if ( arrdim(X) != 2 )
    error("The array must be two dimensional to take transpose.")
  end

  # Permutation 
  indexperm=[2 1];

  # Dimension of transpose
  Z.ndim=X.ndim;

  # Index ranges of transpose
  Z.dims=X.dims(indexperm);

  # Elements of transpose
  Xcoord=arrindexorder(X.dims);
  Xcoordperm=Xcoord(:,indexperm);
  
  for index=1:prod(X.dims)
    Xarrindex=arrcoord2index(Xcoordperm(index,:),Z.dims);
    Z.elems(Xarrindex)=X.elems(index);
  end

endfunction

