function Z = arrreg2voigt(X) 
# usage: Z = arrreg2voigt(X) 
#
# This function takes a 2n-dimensional array labelled in regular notation 
# and generates the corresponding n-dimensional array in Voigt notation.
#
# Uses:  arrindex2coord.m, arrcoord2index.m, arrvoigtmapinv.m

# Author:  Ronald Kumon

  # Error checking
  if ( nargin != 1 )
    usage("arrreg2voigt(X)");
  endif

  if ( is_struct(X) != 1 ) 
    error("The input argument is a not a multidimensional array structure.");
  end

  if ( is_tensor(X) != 1 ) 
    error("The input array is not a tensor.");
  end

  if ( rem(X.ndim,2) != 0)
    error("The input array does not have an even number of dimensions.")
  end

  if ( X.dims(1) != 3 ) 
    error("The input array is not in appropriate form (three indices in each dimension).");
  end

  # Number of dimensions in full array
  Z.ndim=X.ndim/2;

  # Index ranges in full array 
  Z.dims=6*ones(Z.ndim,1);

  # Elements of full array
  for arrindex=1:prod(Z.dims)
    Zcoordindiv=arrindex2coord(arrindex,Z.dims);
    for index=1:Z.ndim
      Xvoigtindex(arrindex,(2*index-1):(2*index))=arrvoigtmapinv(Zcoordindiv(index));
    end
    Xindex=arrcoord2index(Xvoigtindex(arrindex,:),X.dims);
    Z.elems(arrindex)=X.elems(Xindex);
  end

endfunction

