function Z = arrvoigt2reg(X) 
# usage: Z = arrvoigt2reg(X) 
#
# This function takes a n-dimensional array labelled in Voigt notation 
# and generates the corresponding 2n-dimensional array in regular notation.
#
# Uses:  arrindex2coord.m, arrcoord2index.m, arrvoigtmap.m

# Author:  Ronald Kumon

  # Error checking
  if ( nargin != 1 )
    usage("arrvoigt2reg(X)");
  endif

  if ( is_struct(X) != 1 ) 
    error("The input argument is a not a multidimensional array structure.");
  end

  if ( ( X.ndim > 1 ) && ( is_tensor(X) != 1 ) )
    error("The input array is not a tensor.");
  end
  
  if ( X.dims(1) != 6 ) 
    error("The input array is not in Voigt form (six indices in each dimension).");
  end

  # Number of dimensions in full array
  Z.ndim=2*X.ndim;

  # Index ranges in full array 
  Z.dims=3*ones(Z.ndim,1);

  # Elements of full array
  for arrindex=1:prod(Z.dims)
    Zcoordindiv=arrindex2coord(arrindex,Z.dims);
    for index=1:X.ndim
      Zcoordpair=Zcoordindiv((2*index-1):(2*index));
      Zvoigtindex(index)=arrvoigtmap(Zcoordpair);
    end
    Xindex=arrcoord2index(Zvoigtindex,X.dims);
    Z.elems(arrindex)=X.elems(Xindex);
  end

endfunction

