function Z = arrvoigt2regtwo(X) 
# usage: Z = arrvoigt2regtwo(X) 
#
# This function takes a 1-dimensional strain array labelled in Voigt notation 
# and generates the corresponding 2-dimensional array in regular notation.
# As is conventional for certain tensors (e.g., strain, compliance), 
# a factor of one half is included for every index which is equal to 
# 4, 5, or 6.
# [see B. A. Auld, Acoustic Fields and Waves in Solids (John Wiley 
# & Sons, New York, 1973), Sections 1F and 3C.]

# Author:  Ronald Kumon

  # Error checking
  if ( nargin != 1 )
    usage("arrvoigt2regtwo(X)");
  endif

  if ( is_struct(X) != 1 ) 
    error("The input argument is a not a multidimensional array structure.");
  end

  if ( ( X.ndim > 1 ) && ( is_tensor(X) != 1 ) )
    error("The input array is not a tensor.");
  end
   
  if ( X.dims(1) != 6 ) 
    error("The input array is not in Voigt form (six indices in each dimension).");
  end

  warning("Voigt to regular index conversion with factors of two used.")

  # Number of dimensions in full array
  Z.ndim=2*X.ndim;

  # Index ranges in full array 
  Z.dims=3*ones(Z.ndim,1);

  # Elements of full array
  for arrindex=1:prod(Z.dims)
    factor=1;
    Zcoordindiv=arrindex2coord(arrindex,Z.dims);
    for index=1:X.ndim
      Zcoordpair=Zcoordindiv((2*index-1):(2*index));
      Zvoigtindex(index)=arrvoigtmap(Zcoordpair);
      if ( Zvoigtindex(index) > 3 )
        factor=factor/2;
      end
    end
    Xindex=arrcoord2index(Zvoigtindex,X.dims);
    Z.elems(arrindex)=X.elems(Xindex)*factor;
  end

endfunction

