function y = arrvoigtmap(x) 
# usage: y = arrvoigtmap(x) 
#
# This function maps a pair of indices "x" to a single index "y" 
# according to the Voigt convention:
#   (11) -> 1, (22) -> 2, (33) -> 3
#   (23) -> 4, (13) -> 5, (12) -> 6
#   (32) -> 4, (31) -> 5, (21) -> 6

# Author:  Ronald Kumon

  # Error checking
  if ( nargin != 1 )
    usage("arrvoigtmap(x)");
  endif

  if ( is_vector(x) != 1 ) 
    error("The input argument must be in vector form.");
  end

  if ( length(x) != 2 ) 
    error("The input argument must be a pair of indices.");
  end

  if ( any(x < 1) || any(x > 3) )
    error("The values of the input indices must be between 1 and 3.");
  end

  x1=x(1);
  x2=x(2);

  if ( x1==x2 )
    y=x1;
  else
    y=9-x1-x2;
  end

endfunction

