# effconst.m
#
# This script computes the effective elastic constants of material.


# Material properties
#
# Copper
rho=8960;         # Density in natural state [kg/m^3]
c11=202.1e9;      # Second order elastic constants in natural state [Pa]
c12=106.4e9;
c44=48e9;
c111=-2614e9;     # Third order elastic constants in natural state [Pa]
c112=-522e9;
c123=-251e9;
c144=-135.5e9;
c155=-523e9;
c456=-193.75e9;

# Format of input vectors for the elasticfill routines: 
#triclinicvec2=[11 12 13 14 15 16 22 \
#               23 24 25 26 33 34 35 \
#               36 44 45 46 55 56 66];
#triclinicvec3=[111 112 113 114 115 116 122 \
#               123 124 125 126 133 134 135 \
#               136 144 145 146 155 156 166 \ 
#               222 223 224 225 226 233 234 \ 
#               235 236 244 245 246 255 256 \ 
#               266 333 334 335 336 344 345 \ 
#               346 355 356 366 444 445 446 \ 
#               455 456 466 555 556 566 666];

cubicvec2=[c11 c12 c12   0   0   0 c11 \ 
           c12   0   0   0 c11   0   0 \ 
             0 c44   0   0 c44   0 c44];
c2voigt=elasticfill2(cubicvec2);
c2voigtmat=arr2mat(c2voigt);
c2=arrvoigt2reg(c2voigt);
cubicvec3=[c111 c112 c112    0    0    0 c112 \ 
           c123    0    0    0 c112    0    0 \
              0 c144    0    0 c155    0 c155 \
           c111 c112    0    0    0 c112    0 \ 
              0    0 c155    0    0 c144    0 \ 
           c155 c111    0    0    0 c155    0 \
              0 c155    0 c144    0    0    0 \ 
              0 c456    0    0    0    0    0];
c3voigt=elasticfill3(cubicvec3);
c3=arrvoigt2reg(c3voigt);

# Pre-stress [Pa]
taumat=[0 0 0; 0 0 0; 0 0 368e6];
tau=mat2arr(taumat);
tauvoigt=arrreg2voigt(tau);
tauvec=arr2mat(tauvoigt);

# Displacement gradients due to pre-stress
taunine=arrval(tau);
c2nine=arrassgn(2,[9 9],arrval(c2));
c2nineinv=inv(arr2mat(c2nine));
