function Z=elasticfill2(vec)
# usage: Z=elasticfill2(vec) 
#
# This function takes as input a 21 element vector representing the 
# the maximum number of independent constants for a second-order elastic
# tensor and fills in the 15 remaining components of the full 36 constant
# abbreviated tensor.  The ordering of the vector is taken from Table 1 
# of R. F. S. Hearmon, "The elastic constants of crystals and other 
# anisotropic materials," Landolt-Bornstein, Vol. 11 (Springer-Verlag, 
# Berlin, 1979).
#
# Uses: arrcoord2index.m

# Author:  Ronald Kumon

  # Error checking
  if ( nargin != 1 )
    usage("elasticfill2(vec)");
  endif

  if ( ( is_vector(vec) != 1 ) || ( length(vec) != 21 ) ) 
    error("The input argument is a not a 21 element vector.");
  end

  # Array dimensions and index ranges
  Z.ndim=2;
  Z.dims=[6 6].';
 
  # Compute elements
  count=1;
  for index1=1:6
    for index2=index1:6
       coord1=[index1 index2];
       coord2=[index2 index1];
       Z.elems(arrcoord2index(coord1,Z.dims))=vec(count);
       Z.elems(arrcoord2index(coord2,Z.dims))=vec(count);
       count=count+1;
    end
  end
  
end
  
