function Z=elasticfill3(vec)
# usage: Z=elasticfill3(vec) 
#
# This function takes as input a 56 element vector representing the 
# the maximum number of independent constants for a third-order elastic
# tensor and fills in the 160 remaining components of the full 216 constant
# abbreviated tensor.  The ordering of the vector is taken from Table 6 
#  of  R. F. S. Hearmon, "The third- and higher-order elastic constants,"
#  Landolt-Bornstein, Vol. 11 (Springer-Verlag, Berlin, 1979).
#
# Uses: arrcoord2index.m

# Author:  Ronald Kumon

  # Error checking
  if ( nargin != 1 )
    usage("elasticfill2(vec)");
  endif

  if ( ( is_vector(vec) != 1 ) || ( length(vec) != 56 ) ) 
    error("The input argument is a not a 56 element vector.");
  end

  # Array dimensions and index ranges
  Z.ndim=3;
  Z.dims=[6 6 6].';
  
  # Compute elements
  count=1;
  for index1=1:6
    for index2=index1:6
      for index3=index2:6
        coord1=[index1 index2 index3];
        coord2=[index1 index3 index2];
        coord3=[index2 index1 index3];
        coord4=[index2 index3 index1];
        coord5=[index3 index1 index2];
        coord6=[index3 index2 index1];
        Z.elems(arrcoord2index(coord1,Z.dims))=vec(count);
        Z.elems(arrcoord2index(coord2,Z.dims))=vec(count);
        Z.elems(arrcoord2index(coord3,Z.dims))=vec(count);
        Z.elems(arrcoord2index(coord4,Z.dims))=vec(count);
        Z.elems(arrcoord2index(coord5,Z.dims))=vec(count);
        Z.elems(arrcoord2index(coord6,Z.dims))=vec(count);
        count=count+1;
      end
    end
  end
  
end
  
