function X = mat2arr(mat) 
# usage: X = mat2arr(mat)
#
# This function converts a matrix into a structure appropriate
# for use with other multidimensional arrays.  All row vectors are 
# converted to column vectors, i.e., no distinction is made
# between row vector and column vectors.

# Author:  Ronald Kumon

  # Error checking
  if ( nargin != 1 )
    usage("mat2arr(mat)");
  endif

  if ( is_matrix(mat) != 1 )
    error("Input argument is not a matrix.")
  end

  # Perform conversion from matrix to multidimensional array.
  matsize=size(mat);
  if ( ( matsize(1) == 1 ) && ( matsize(2) == 1 ) )  # scalar 
     X.ndim=0;
     X.dims=1;
     X.elems=mat;
  elseif ( ( matsize(1) == 1 ) || ( matsize(2) == 1 ) ) # vector
     X.ndim=1;
     X.dims=max(matsize);
     if ( matsize(1) < matsize(2) )
       X.elems=mat.';
     else 
       X.elems=mat; 
     end
  else # matrix
     X.ndim=2;
     X.dims=matsize.';
     vector=zeros(prod(matsize),1);
     rows=matsize(1);
     cols=matsize(2);
     for index1=1:rows
       for index2=1:cols
         vectorindex=cols*(index1-1)+index2;
         X.elems(vectorindex)=mat(index1,index2);
       end
     end
  end   

endfunction

